=======
History
=======

0.2.4 (2018-06-15)
------------------

* Removed dead code, removed executable file permission
* Removed appveyor related files

0.2.3 (2018-06-15)
------------------

* Removed shebangs from scripts

0.2.2 (2018-06-01)
------------------

* Fixed a bug in updates with provided release information
* Fixed a bug in get_info_from_release_string()

0.2.1 (2018-05-30)
------------------

* Fixed a bug where invalid characters were accepted in release name

0.2.0 (2018-05-29)
------------------

* Added version information in output files
* Added sub-command "version" to output name and version
* Added option "--final" to mark modified release as released
* Prevent releases marked with the special comment "# Released" to be modified
* Allow existing release update
* Detect duplicated symbols given as input

0.1.0 (2018-05-09)
------------------

* First release on PyPI.
